info = {
    "name": "kw",
    "date_order": "YMD",
    "january": [
        "gen",
        "mis genver"
    ],
    "february": [
        "hwe",
        "mis hwevrer"
    ],
    "march": [
        "meu",
        "mis meurth"
    ],
    "april": [
        "ebr",
        "mis ebrel"
    ],
    "may": [
        "me",
        "mis me"
    ],
    "june": [
        "met",
        "mis metheven"
    ],
    "july": [
        "gor",
        "mis gortheren"
    ],
    "august": [
        "est",
        "mis est"
    ],
    "september": [
        "gwn",
        "mis gwynngala"
    ],
    "october": [
        "hed",
        "mis hedra"
    ],
    "november": [
        "du",
        "mis du"
    ],
    "december": [
        "kev",
        "mis kevardhu"
    ],
    "monday": [
        "dy lun",
        "lun"
    ],
    "tuesday": [
        "dy meurth",
        "mth"
    ],
    "wednesday": [
        "dy merher",
        "mhr"
    ],
    "thursday": [
        "dy yow",
        "yow"
    ],
    "friday": [
        "dy gwener",
        "gwe"
    ],
    "saturday": [
        "dy sadorn",
        "sad"
    ],
    "sunday": [
        "dy sul",
        "sul"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "year"
    ],
    "month": [
        "month"
    ],
    "week": [
        "week"
    ],
    "day": [
        "day"
    ],
    "hour": [
        "hour"
    ],
    "minute": [
        "minute"
    ],
    "second": [
        "second"
    ],
    "relative-type": {
        "0 day ago": [
            "today"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "yesterday"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "tomorrow"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
