info = {
    "name": "uz-Latn",
    "date_order": "DMY",
    "january": [
        "yan",
        "yanvar"
    ],
    "february": [
        "fev",
        "fevral"
    ],
    "march": [
        "mar",
        "mart"
    ],
    "april": [
        "apr",
        "aprel"
    ],
    "may": [
        "may"
    ],
    "june": [
        "iyn",
        "iyun"
    ],
    "july": [
        "iyl",
        "iyul"
    ],
    "august": [
        "avg",
        "avgust"
    ],
    "september": [
        "sen",
        "sentabr"
    ],
    "october": [
        "okt",
        "oktabr"
    ],
    "november": [
        "noy",
        "noyabr"
    ],
    "december": [
        "dek",
        "dekabr"
    ],
    "monday": [
        "dush",
        "dushanba"
    ],
    "tuesday": [
        "sesh",
        "seshanba"
    ],
    "wednesday": [
        "chor",
        "chorshanba"
    ],
    "thursday": [
        "pay",
        "payshanba"
    ],
    "friday": [
        "jum",
        "juma"
    ],
    "saturday": [
        "shan",
        "shanba"
    ],
    "sunday": [
        "yak",
        "yakshanba"
    ],
    "am": [
        "to"
    ],
    "pm": [
        "tk"
    ],
    "year": [
        "yil"
    ],
    "month": [
        "oy"
    ],
    "week": [
        "hafta"
    ],
    "day": [
        "kun"
    ],
    "hour": [
        "soat"
    ],
    "minute": [
        "daq",
        "daqiqa"
    ],
    "second": [
        "son",
        "soniya"
    ],
    "relative-type": {
        "0 day ago": [
            "bugun"
        ],
        "0 hour ago": [
            "shu soatda"
        ],
        "0 minute ago": [
            "shu daqiqada"
        ],
        "0 month ago": [
            "shu oy"
        ],
        "0 second ago": [
            "hozir"
        ],
        "0 week ago": [
            "shu hafta"
        ],
        "0 year ago": [
            "bu yil",
            "shu yil"
        ],
        "1 day ago": [
            "kecha"
        ],
        "1 month ago": [
            "o‘tgan oy"
        ],
        "1 week ago": [
            "o‘tgan hafta"
        ],
        "1 year ago": [
            "o'tgan yil",
            "o‘tgan yil"
        ],
        "in 1 day": [
            "ertaga"
        ],
        "in 1 month": [
            "keyingi oy"
        ],
        "in 1 week": [
            "keyingi hafta"
        ],
        "in 1 year": [
            "keyingi yil"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+[.,]?\\d*) kun oldin"
        ],
        "\\1 hour ago": [
            "(\\d+[.,]?\\d*) soat oldin"
        ],
        "\\1 minute ago": [
            "(\\d+[.,]?\\d*) daqiqa oldin"
        ],
        "\\1 month ago": [
            "(\\d+[.,]?\\d*) oy oldin"
        ],
        "\\1 second ago": [
            "(\\d+[.,]?\\d*) soniya oldin"
        ],
        "\\1 week ago": [
            "(\\d+[.,]?\\d*) hafta oldin"
        ],
        "\\1 year ago": [
            "(\\d+[.,]?\\d*) yil oldin"
        ],
        "in \\1 day": [
            "(\\d+[.,]?\\d*) kundan keyin"
        ],
        "in \\1 hour": [
            "(\\d+[.,]?\\d*) soatdan keyin"
        ],
        "in \\1 minute": [
            "(\\d+[.,]?\\d*) daqiqadan keyin"
        ],
        "in \\1 month": [
            "(\\d+[.,]?\\d*) oydan keyin"
        ],
        "in \\1 second": [
            "(\\d+[.,]?\\d*) soniyadan keyin"
        ],
        "in \\1 week": [
            "(\\d+[.,]?\\d*) haftadan keyin"
        ],
        "in \\1 year": [
            "(\\d+[.,]?\\d*) yildan keyin"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
