info = {
    "name": "fa",
    "date_order": "YMD",
    "january": [
        "ژانویه",
        "ژانویهٔ",
        "جنوری"
    ],
    "february": [
        "فوریه",
        "فوریهٔ",
        "فبروری"
    ],
    "march": [
        "مارس",
        "مارچ"
    ],
    "april": [
        "آوریل",
        "اپریل"
    ],
    "may": [
        "مه",
        "مهٔ",
        "می"
    ],
    "june": [
        "ژوئن",
        "جون"
    ],
    "july": [
        "ژوئیه",
        "ژوئیهٔ",
        "جولای"
    ],
    "august": [
        "اوت",
        "آگست"
    ],
    "september": [
        "سپتامبر",
        "سپتمبر"
    ],
    "october": [
        "اکتبر",
        "اکتوبر"
    ],
    "november": [
        "نوامبر",
        "نومبر"
    ],
    "december": [
        "دسامبر",
        "دسمبر"
    ],
    "monday": [
        "دوشنبه"
    ],
    "tuesday": [
        "سه‌شنبه",
        "سهشنبه"
    ],
    "wednesday": [
        "چهارشنبه",
        "چهار شنبه"
    ],
    "thursday": [
        "پنجشنبه",
        "پنج شنبه"
    ],
    "friday": [
        "جمعه"
    ],
    "saturday": [
        "شنبه",
        "روز شنبه",
        "دو شنبه",
        "د"
    ],
    "sunday": [
        "یکشنبه"
    ],
    "am": [
        "قبل‌ازظهر",
        "قظ"
    ],
    "pm": [
        "بظ",
        "بعدازظهر"
    ],
    "year": [
        "سال"
    ],
    "month": [
        "ماه"
    ],
    "week": [
        "هفته"
    ],
    "day": [
        "روز"
    ],
    "hour": [
        "ساعت"
    ],
    "minute": [
        "دقیقه"
    ],
    "second": [
        "ثانیه",
        "دوم"
    ],
    "relative-type": {
        "0 day ago": [
            "امروز"
        ],
        "0 hour ago": [
            "همین ساعت"
        ],
        "0 minute ago": [
            "همین دقیقه"
        ],
        "0 month ago": [
            "این ماه"
        ],
        "0 second ago": [
            "اکنون"
        ],
        "0 week ago": [
            "این هفته"
        ],
        "0 year ago": [
            "امسال"
        ],
        "1 day ago": [
            "دیروز"
        ],
        "1 month ago": [
            "ماه پیش",
            "ماه گذشته"
        ],
        "1 week ago": [
            "هفتهٔ گذشته"
        ],
        "1 year ago": [
            "سال گذشته"
        ],
        "in 1 day": [
            "فردا"
        ],
        "in 1 month": [
            "ماه آینده"
        ],
        "in 1 week": [
            "هفتهٔ آینده"
        ],
        "in 1 year": [
            "سال آینده"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+[.,]?\\d*) روز پیش"
        ],
        "\\1 hour ago": [
            "(\\d+[.,]?\\d*) ساعت پیش"
        ],
        "\\1 minute ago": [
            "(\\d+[.,]?\\d*) دقیقه پیش"
        ],
        "\\1 month ago": [
            "(\\d+[.,]?\\d*) ماه پیش"
        ],
        "\\1 second ago": [
            "(\\d+[.,]?\\d*) ثانیه پیش"
        ],
        "\\1 week ago": [
            "(\\d+[.,]?\\d*) هفته پیش"
        ],
        "\\1 year ago": [
            "(\\d+[.,]?\\d*) سال پیش"
        ],
        "in \\1 day": [
            "(\\d+[.,]?\\d*) روز بعد"
        ],
        "in \\1 hour": [
            "(\\d+[.,]?\\d*) ساعت بعد"
        ],
        "in \\1 minute": [
            "(\\d+[.,]?\\d*) دقیقه بعد"
        ],
        "in \\1 month": [
            "(\\d+[.,]?\\d*) ماه بعد"
        ],
        "in \\1 second": [
            "(\\d+[.,]?\\d*) ثانیه بعد"
        ],
        "in \\1 week": [
            "(\\d+[.,]?\\d*) هفته بعد"
        ],
        "in \\1 year": [
            "(\\d+[.,]?\\d*) سال بعد"
        ]
    },
    "locale_specific": {
        "fa-AF": {
            "name": "fa-AF",
            "january": [
                "جنو",
                "جنوری"
            ],
            "february": [
                "فبروری"
            ],
            "march": [
                "مارچ"
            ],
            "april": [
                "اپریل"
            ],
            "may": [
                "می"
            ],
            "june": [
                "جون"
            ],
            "july": [
                "جول",
                "جولای"
            ],
            "august": [
                "اگست"
            ],
            "september": [
                "سپتمبر"
            ],
            "october": [
                "اکتوبر"
            ],
            "november": [
                "نومبر"
            ],
            "december": [
                "دسم",
                "دسمبر"
            ]
        }
    },
    "sentence_splitter_group": 6,
    "ago": [
        "پیش"
    ],
    "in": [
        "در"
    ],
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
