info = {
    "name": "dua",
    "date_order": "DMY",
    "january": [
        "di",
        "dimɔ́di"
    ],
    "february": [
        "ŋgɔn",
        "ŋgɔndɛ"
    ],
    "march": [
        "sɔŋ",
        "sɔŋɛ"
    ],
    "april": [
        "diɓ",
        "diɓáɓá"
    ],
    "may": [
        "emi",
        "emiasele"
    ],
    "june": [
        "esɔ",
        "esɔpɛsɔpɛ"
    ],
    "july": [
        "mad",
        "madiɓɛ́díɓɛ́"
    ],
    "august": [
        "diŋ",
        "diŋgindi"
    ],
    "september": [
        "nyɛt",
        "nyɛtɛki"
    ],
    "october": [
        "may",
        "mayésɛ́"
    ],
    "november": [
        "tin",
        "tiníní"
    ],
    "december": [
        "elá",
        "eláŋgɛ́"
    ],
    "monday": [
        "mɔ́s",
        "mɔ́sú"
    ],
    "tuesday": [
        "kwa",
        "kwasú"
    ],
    "wednesday": [
        "muk",
        "mukɔ́sú"
    ],
    "thursday": [
        "ŋgi",
        "ŋgisú"
    ],
    "friday": [
        "ɗón",
        "ɗónɛsú"
    ],
    "saturday": [
        "esa",
        "esaɓasú"
    ],
    "sunday": [
        "ét",
        "éti"
    ],
    "am": [
        "idiɓa"
    ],
    "pm": [
        "ebyámu"
    ],
    "year": [
        "mbú"
    ],
    "month": [
        "mɔ́di"
    ],
    "week": [
        "disama"
    ],
    "day": [
        "búnyá"
    ],
    "hour": [
        "ŋgandɛ"
    ],
    "minute": [
        "ndɔkɔ"
    ],
    "second": [
        "píndí"
    ],
    "relative-type": {
        "0 day ago": [
            "wɛ́ŋgɛ̄"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "kíɛlɛ nítómb́í"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "kíɛlɛ"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
