info = {
    "name": "gsw",
    "date_order": "DMY",
    "january": [
        "jan",
        "januar"
    ],
    "february": [
        "feb",
        "februar"
    ],
    "march": [
        "mär",
        "märz"
    ],
    "april": [
        "apr",
        "april"
    ],
    "may": [
        "mai"
    ],
    "june": [
        "jun",
        "juni"
    ],
    "july": [
        "jul",
        "juli"
    ],
    "august": [
        "aug",
        "auguscht"
    ],
    "september": [
        "sep",
        "septämber"
    ],
    "october": [
        "okt",
        "oktoober"
    ],
    "november": [
        "nov",
        "novämber"
    ],
    "december": [
        "dez",
        "dezämber"
    ],
    "monday": [
        "mä",
        "määntig"
    ],
    "tuesday": [
        "zi",
        "ziischtig"
    ],
    "wednesday": [
        "mi",
        "mittwuch"
    ],
    "thursday": [
        "du",
        "dunschtig"
    ],
    "friday": [
        "fr",
        "friitig"
    ],
    "saturday": [
        "sa",
        "samschtig"
    ],
    "sunday": [
        "su",
        "sunntig"
    ],
    "am": [
        "am vormittag",
        "vorm",
        "vormittag"
    ],
    "pm": [
        "am namittag",
        "nam",
        "namittag"
    ],
    "year": [
        "jaar"
    ],
    "month": [
        "monet"
    ],
    "week": [
        "wuche"
    ],
    "day": [
        "tag"
    ],
    "hour": [
        "schtund"
    ],
    "minute": [
        "minuute"
    ],
    "second": [
        "sekunde"
    ],
    "relative-type": {
        "0 day ago": [
            "hüt"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "geschter"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "moorn"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {
        "gsw-FR": {
            "name": "gsw-FR"
        },
        "gsw-LI": {
            "name": "gsw-LI"
        }
    },
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
