info = {
    "name": "hy",
    "date_order": "DMY",
    "january": [
        "հնվ",
        "հունվար",
        "հունվարի"
    ],
    "february": [
        "փետրվար",
        "փետրվարի",
        "փտվ"
    ],
    "march": [
        "մարտ",
        "մարտի",
        "մրտ"
    ],
    "april": [
        "ապր",
        "ապրիլ",
        "ապրիլի"
    ],
    "may": [
        "մայիս",
        "մայիսի",
        "մյս"
    ],
    "june": [
        "հնս",
        "հունիս",
        "հունիսի"
    ],
    "july": [
        "հլս",
        "հուլիս",
        "հուլիսի"
    ],
    "august": [
        "օգոստոս",
        "օգոստոսի",
        "օգս"
    ],
    "september": [
        "սեպ",
        "սեպտեմբեր",
        "սեպտեմբերի"
    ],
    "october": [
        "հոկ",
        "հոկտեմբեր",
        "հոկտեմբերի"
    ],
    "november": [
        "նոյ",
        "նոյեմբեր",
        "նոյեմբերի"
    ],
    "december": [
        "դեկ",
        "դեկտեմբեր",
        "դեկտեմբերի"
    ],
    "monday": [
        "երկ",
        "երկուշաբթի"
    ],
    "tuesday": [
        "երեքշաբթի",
        "երք"
    ],
    "wednesday": [
        "չորեքշաբթի",
        "չրք"
    ],
    "thursday": [
        "հինգշաբթի",
        "հնգ"
    ],
    "friday": [
        "ուր",
        "ուրբաթ"
    ],
    "saturday": [
        "շաբաթ",
        "շբթ"
    ],
    "sunday": [
        "կիր",
        "կիրակի"
    ],
    "am": [
        "am",
        "կա"
    ],
    "pm": [
        "pm",
        "կհ"
    ],
    "year": [
        "տ",
        "տարի"
    ],
    "month": [
        "ամիս",
        "ամս"
    ],
    "week": [
        "շաբ",
        "շաբաթ"
    ],
    "day": [
        "օր"
    ],
    "hour": [
        "ժ",
        "ժամ"
    ],
    "minute": [
        "ր",
        "րոպե"
    ],
    "second": [
        "վ",
        "վայրկյան"
    ],
    "relative-type": {
        "0 day ago": [
            "այսօր"
        ],
        "0 hour ago": [
            "այս ժամին"
        ],
        "0 minute ago": [
            "այս րոպեին"
        ],
        "0 month ago": [
            "այս ամիս"
        ],
        "0 second ago": [
            "այժմ"
        ],
        "0 week ago": [
            "այս շաբաթ"
        ],
        "0 year ago": [
            "այս տարի"
        ],
        "1 day ago": [
            "երեկ"
        ],
        "1 month ago": [
            "անցյալ ամիս",
            "նախորդ ամիս"
        ],
        "1 week ago": [
            "նախորդ շաբաթ"
        ],
        "1 year ago": [
            "նախորդ տարի"
        ],
        "in 1 day": [
            "վաղը"
        ],
        "in 1 month": [
            "հաջորդ ամիս"
        ],
        "in 1 week": [
            "հաջորդ շաբաթ"
        ],
        "in 1 year": [
            "հաջորդ տարի"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+[.,]?\\d*) օր առաջ"
        ],
        "\\1 hour ago": [
            "(\\d+[.,]?\\d*) ժ առաջ",
            "(\\d+[.,]?\\d*) ժամ առաջ"
        ],
        "\\1 minute ago": [
            "(\\d+[.,]?\\d*) ր առաջ",
            "(\\d+[.,]?\\d*) րոպե առաջ"
        ],
        "\\1 month ago": [
            "(\\d+[.,]?\\d*) ամիս առաջ"
        ],
        "\\1 second ago": [
            "(\\d+[.,]?\\d*) վ առաջ",
            "(\\d+[.,]?\\d*) վայրկյան առաջ",
            "(\\d+[.,]?\\d*) վրկ առաջ"
        ],
        "\\1 week ago": [
            "(\\d+[.,]?\\d*) շաբ առաջ",
            "(\\d+[.,]?\\d*) շաբաթ առաջ"
        ],
        "\\1 year ago": [
            "(\\d+[.,]?\\d*) տ առաջ",
            "(\\d+[.,]?\\d*) տարի առաջ"
        ],
        "in \\1 day": [
            "(\\d+[.,]?\\d*) օրից"
        ],
        "in \\1 hour": [
            "(\\d+[.,]?\\d*) ժ-ից",
            "(\\d+[.,]?\\d*) ժամից"
        ],
        "in \\1 minute": [
            "(\\d+[.,]?\\d*) ր-ից",
            "(\\d+[.,]?\\d*) րոպեից"
        ],
        "in \\1 month": [
            "(\\d+[.,]?\\d*) ամսից"
        ],
        "in \\1 second": [
            "(\\d+[.,]?\\d*) վ-ից",
            "(\\d+[.,]?\\d*) վայրկյանից",
            "(\\d+[.,]?\\d*) վրկ-ից"
        ],
        "in \\1 week": [
            "(\\d+[.,]?\\d*) շաբ անց",
            "(\\d+[.,]?\\d*) շաբ-ից",
            "(\\d+[.,]?\\d*) շաբաթից"
        ],
        "in \\1 year": [
            "(\\d+[.,]?\\d*) տարուց"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
