info = {
    "name": "mas",
    "date_order": "DMY",
    "january": [
        "dal",
        "oladalʉ́"
    ],
    "february": [
        "ará",
        "arát"
    ],
    "march": [
        "ɔɛn",
        "ɔɛnɨ́ɔɨŋɔk"
    ],
    "april": [
        "doy",
        "olodoyíóríê inkókúâ"
    ],
    "may": [
        "lép",
        "oloilépūnyīē inkókúâ"
    ],
    "june": [
        "kújúɔrɔk",
        "rok"
    ],
    "july": [
        "mórusásin",
        "sás"
    ],
    "august": [
        "bɔ́r",
        "ɔlɔ́ɨ́bɔ́rárɛ"
    ],
    "september": [
        "kús",
        "kúshîn"
    ],
    "october": [
        "gís",
        "olgísan"
    ],
    "november": [
        "pʉshʉ́ka",
        "shʉ́"
    ],
    "december": [
        "ntʉ́",
        "ntʉ́ŋʉ́s"
    ],
    "monday": [
        "jtt",
        "jumatátu"
    ],
    "tuesday": [
        "jnn",
        "jumane"
    ],
    "wednesday": [
        "jtn",
        "jumatánɔ"
    ],
    "thursday": [
        "alaámisi",
        "alh"
    ],
    "friday": [
        "iju",
        "jumáa"
    ],
    "saturday": [
        "jmo",
        "jumamósi"
    ],
    "sunday": [
        "jpi",
        "jumapílí"
    ],
    "am": [
        "ɛnkakɛnyá"
    ],
    "pm": [
        "ɛndámâ"
    ],
    "year": [
        "ɔlárì"
    ],
    "month": [
        "ɔlápà"
    ],
    "week": [
        "ewíkî"
    ],
    "day": [
        "ɛnkɔlɔ́ŋ"
    ],
    "hour": [
        "ɛ́sáâ"
    ],
    "minute": [
        "oldákikaè"
    ],
    "second": [
        "sekunde"
    ],
    "relative-type": {
        "0 day ago": [
            "táatá"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "ŋolé"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "tááisérè"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {
        "mas-TZ": {
            "name": "mas-TZ"
        }
    },
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
