info = {
    "name": "shi-Latn",
    "date_order": "DMY",
    "january": [
        "inn",
        "innayr"
    ],
    "february": [
        "bṛa",
        "bṛayṛ"
    ],
    "march": [
        "maṛ",
        "maṛṣ"
    ],
    "april": [
        "ibr",
        "ibrir"
    ],
    "may": [
        "may",
        "mayyu"
    ],
    "june": [
        "yun",
        "yunyu"
    ],
    "july": [
        "yul",
        "yulyuz"
    ],
    "august": [
        "ɣuc",
        "ɣuct"
    ],
    "september": [
        "cut",
        "cutanbir"
    ],
    "october": [
        "ktu",
        "ktubr"
    ],
    "november": [
        "nuw",
        "nuwanbir"
    ],
    "december": [
        "duj",
        "dujanbir"
    ],
    "monday": [
        "ayn",
        "aynas"
    ],
    "tuesday": [
        "asi",
        "asinas"
    ],
    "wednesday": [
        "akṛ",
        "akṛas"
    ],
    "thursday": [
        "akw",
        "akwas"
    ],
    "friday": [
        "asim",
        "asimwas"
    ],
    "saturday": [
        "asiḍ",
        "asiḍyas"
    ],
    "sunday": [
        "asa",
        "asamas"
    ],
    "am": [
        "tifawt"
    ],
    "pm": [
        "tadggʷat"
    ],
    "year": [
        "asggʷas"
    ],
    "month": [
        "ayyur"
    ],
    "week": [
        "imalass"
    ],
    "day": [
        "ass"
    ],
    "hour": [
        "tasragt"
    ],
    "minute": [
        "tusdidt"
    ],
    "second": [
        "tasint"
    ],
    "relative-type": {
        "0 day ago": [
            "assa"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "iḍlli"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "askka"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
