info = {
    "name": "zu",
    "date_order": "MDY",
    "january": [
        "jan",
        "januwari",
        "umasingana"
    ],
    "february": [
        "feb",
        "februwari"
    ],
    "march": [
        "mas",
        "mashi"
    ],
    "april": [
        "eph",
        "ephreli"
    ],
    "may": [
        "mey",
        "meyi"
    ],
    "june": [
        "jun",
        "juni"
    ],
    "july": [
        "jul",
        "julayi"
    ],
    "august": [
        "aga",
        "agasti"
    ],
    "september": [
        "sep",
        "septhemba"
    ],
    "october": [
        "okt",
        "okthoba"
    ],
    "november": [
        "nov",
        "novemba"
    ],
    "december": [
        "dis",
        "disemba"
    ],
    "monday": [
        "mso",
        "umsombuluko"
    ],
    "tuesday": [
        "bil",
        "ulwesibili"
    ],
    "wednesday": [
        "tha",
        "ulwesithathu"
    ],
    "thursday": [
        "sin",
        "ulwesine"
    ],
    "friday": [
        "hla",
        "ulwesihlanu"
    ],
    "saturday": [
        "mgq",
        "umgqibelo"
    ],
    "sunday": [
        "isonto",
        "son"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "unyaka"
    ],
    "month": [
        "inyanga"
    ],
    "week": [
        "iviki"
    ],
    "day": [
        "usuku"
    ],
    "hour": [
        "ihora"
    ],
    "minute": [
        "iminithi"
    ],
    "second": [
        "isekhondi"
    ],
    "relative-type": {
        "0 day ago": [
            "namhlanje"
        ],
        "0 hour ago": [
            "leli hora"
        ],
        "0 minute ago": [
            "leli minithi"
        ],
        "0 month ago": [
            "le nyanga"
        ],
        "0 second ago": [
            "manje"
        ],
        "0 week ago": [
            "leli viki"
        ],
        "0 year ago": [
            "kulo nyaka"
        ],
        "1 day ago": [
            "izolo"
        ],
        "1 month ago": [
            "inyanga edlule"
        ],
        "1 week ago": [
            "iviki eledlule"
        ],
        "1 year ago": [
            "onyakeni odlule"
        ],
        "in 1 day": [
            "kusasa"
        ],
        "in 1 month": [
            "inyanga ezayo"
        ],
        "in 1 week": [
            "iviki elizayo"
        ],
        "in 1 year": [
            "unyaka ozayo"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+[.,]?\\d*) izinsuku ezedlule",
            "(\\d+[.,]?\\d*) usuku olwedlule"
        ],
        "\\1 hour ago": [
            "(\\d+[.,]?\\d*) amahora edlule",
            "(\\d+[.,]?\\d*) ihora eledlule"
        ],
        "\\1 minute ago": [
            "(\\d+[.,]?\\d*) amaminithi edlule",
            "(\\d+[.,]?\\d*) iminithi eledlule"
        ],
        "\\1 month ago": [
            "(\\d+[.,]?\\d*) inyanga edlule",
            "(\\d+[.,]?\\d*) izinyanga ezedlule"
        ],
        "\\1 second ago": [
            "(\\d+[.,]?\\d*) amasekhondi edlule",
            "(\\d+[.,]?\\d*) isekhondi eledlule"
        ],
        "\\1 year ago": [
            "(\\d+[.,]?\\d*) iminyaka edlule",
            "(\\d+[.,]?\\d*) unyaka odlule"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
