info = {
    "name": "haw",
    "date_order": "DMY",
    "january": [
        "ian",
        "ianuali"
    ],
    "february": [
        "pep",
        "pepeluali"
    ],
    "march": [
        "mal",
        "malaki"
    ],
    "april": [
        "'ap",
        "'apelila"
    ],
    "may": [
        "mei"
    ],
    "june": [
        "iun",
        "iune"
    ],
    "july": [
        "iul",
        "iulai"
    ],
    "august": [
        "'au",
        "'aukake"
    ],
    "september": [
        "kep",
        "kepakemapa"
    ],
    "october": [
        "'ok",
        "'okakopa"
    ],
    "november": [
        "now",
        "nowemapa"
    ],
    "december": [
        "kek",
        "kekemapa"
    ],
    "monday": [
        "p1",
        "po'akahi"
    ],
    "tuesday": [
        "p2",
        "po'alua"
    ],
    "wednesday": [
        "p3",
        "po'akolu"
    ],
    "thursday": [
        "p4",
        "po'ahā"
    ],
    "friday": [
        "p5",
        "po'alima"
    ],
    "saturday": [
        "p6",
        "po'aono"
    ],
    "sunday": [
        "lp",
        "lāpule"
    ],
    "am": [
        "am"
    ],
    "pm": [
        "pm"
    ],
    "year": [
        "year"
    ],
    "month": [
        "month"
    ],
    "week": [
        "week"
    ],
    "day": [
        "day"
    ],
    "hour": [
        "hour"
    ],
    "minute": [
        "minute"
    ],
    "second": [
        "second"
    ],
    "relative-type": {
        "0 day ago": [
            "today"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "yesterday"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "tomorrow"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
