info = {
    "name": "kln",
    "date_order": "DMY",
    "january": [
        "mul",
        "mulgul"
    ],
    "february": [
        "ng'atyaato",
        "ngat"
    ],
    "march": [
        "kiptaamo",
        "taa"
    ],
    "april": [
        "iwo",
        "iwootkuut"
    ],
    "may": [
        "mam",
        "mamuut"
    ],
    "june": [
        "paa",
        "paagi"
    ],
    "july": [
        "ng'eiyeet",
        "nge"
    ],
    "august": [
        "roo",
        "rooptui"
    ],
    "september": [
        "bur",
        "bureet"
    ],
    "october": [
        "epe",
        "epeeso"
    ],
    "november": [
        "kipsuunde ne taai",
        "kpt"
    ],
    "december": [
        "kipsuunde nebo aeng'",
        "kpa"
    ],
    "monday": [
        "kot",
        "kotaai"
    ],
    "tuesday": [
        "koaeng'",
        "koo"
    ],
    "wednesday": [
        "kos",
        "kosomok"
    ],
    "thursday": [
        "koa",
        "koang'wan"
    ],
    "friday": [
        "kom",
        "komuut"
    ],
    "saturday": [
        "kol",
        "kolo"
    ],
    "sunday": [
        "kotisap",
        "kts"
    ],
    "am": [
        "karoon",
        "krn"
    ],
    "pm": [
        "koosk",
        "kooskoliny"
    ],
    "year": [
        "kenyit"
    ],
    "month": [
        "arawet"
    ],
    "week": [
        "wikit"
    ],
    "day": [
        "betut"
    ],
    "hour": [
        "sait"
    ],
    "minute": [
        "minitit"
    ],
    "second": [
        "sekondit"
    ],
    "relative-type": {
        "0 day ago": [
            "raini"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "amut"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "mutai"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
