info = {
    "name": "cy",
    "date_order": "DMY",
    "january": [
        "ion",
        "ionawr"
    ],
    "february": [
        "chw",
        "chwef",
        "chwefror"
    ],
    "march": [
        "maw",
        "mawrth"
    ],
    "april": [
        "ebr",
        "ebrill"
    ],
    "may": [
        "mai"
    ],
    "june": [
        "meh",
        "mehefin"
    ],
    "july": [
        "gor",
        "gorff",
        "gorffennaf"
    ],
    "august": [
        "awst"
    ],
    "september": [
        "medi"
    ],
    "october": [
        "hyd",
        "hydref"
    ],
    "november": [
        "tach",
        "tachwedd"
    ],
    "december": [
        "rhag",
        "rhagfyr"
    ],
    "monday": [
        "dydd llun",
        "llun"
    ],
    "tuesday": [
        "dydd mawrth",
        "maw"
    ],
    "wednesday": [
        "dydd mercher",
        "mer"
    ],
    "thursday": [
        "dydd iau",
        "iau"
    ],
    "friday": [
        "dydd gwener",
        "gwe",
        "gwen"
    ],
    "saturday": [
        "dydd sadwrn",
        "sad"
    ],
    "sunday": [
        "dydd sul",
        "sul"
    ],
    "am": [
        "yb"
    ],
    "pm": [
        "yh"
    ],
    "year": [
        "bl",
        "blwyddyn"
    ],
    "month": [
        "mis"
    ],
    "week": [
        "wythnos"
    ],
    "day": [
        "dydd"
    ],
    "hour": [
        "awr"
    ],
    "minute": [
        "mun",
        "munud"
    ],
    "second": [
        "eiliad"
    ],
    "relative-type": {
        "0 day ago": [
            "heddiw"
        ],
        "0 hour ago": [
            "yr awr hon"
        ],
        "0 minute ago": [
            "y funud hon"
        ],
        "0 month ago": [
            "y mis hwn"
        ],
        "0 second ago": [
            "nawr"
        ],
        "0 week ago": [
            "yr wythnos hon"
        ],
        "0 year ago": [
            "eleni"
        ],
        "1 day ago": [
            "ddoe"
        ],
        "1 month ago": [
            "mis diwethaf"
        ],
        "1 week ago": [
            "wythnos ddiwethaf"
        ],
        "1 year ago": [
            "llynedd"
        ],
        "in 1 day": [
            "yfory"
        ],
        "in 1 month": [
            "mis nesaf"
        ],
        "in 1 week": [
            "wythnos nesaf"
        ],
        "in 1 year": [
            "blwyddyn nesaf"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "(\\d+[.,]?\\d*) diwrnod yn ôl"
        ],
        "\\1 hour ago": [
            "(\\d+[.,]?\\d*) awr yn ôl"
        ],
        "\\1 minute ago": [
            "(\\d+[.,]?\\d*) mun yn ôl",
            "(\\d+[.,]?\\d*) munud yn ôl"
        ],
        "\\1 month ago": [
            "(\\d+[.,]?\\d*) mis yn ôl"
        ],
        "\\1 second ago": [
            "(\\d+[.,]?\\d*) eiliad yn ôl"
        ],
        "\\1 week ago": [
            "(\\d+[.,]?\\d*) wythnos yn ôl"
        ],
        "\\1 year ago": [
            "(\\d+[.,]?\\d*) o flynyddoedd yn ôl"
        ],
        "in \\1 day": [
            "ymhen (\\d+[.,]?\\d*) diwrnod"
        ],
        "in \\1 hour": [
            "ymhen (\\d+[.,]?\\d*) awr"
        ],
        "in \\1 minute": [
            "ymhen (\\d+[.,]?\\d*) mun",
            "ymhen (\\d+[.,]?\\d*) munud"
        ],
        "in \\1 month": [
            "ymhen (\\d+[.,]?\\d*) mis"
        ],
        "in \\1 second": [
            "ymhen (\\d+[.,]?\\d*) eiliad"
        ],
        "in \\1 week": [
            "ymhen (\\d+[.,]?\\d*) wythnos"
        ],
        "in \\1 year": [
            "ymhen (\\d+[.,]?\\d*) mlynedd"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
