info = {
    "name": "lu",
    "date_order": "DMY",
    "january": [
        "cio",
        "ciongo"
    ],
    "february": [
        "lui",
        "lùishi"
    ],
    "march": [
        "lus",
        "lusòlo"
    ],
    "april": [
        "muu",
        "mùuyà"
    ],
    "may": [
        "lum",
        "lumùngùlù"
    ],
    "june": [
        "luf",
        "lufuimi"
    ],
    "july": [
        "kab",
        "kabàlàshìpù"
    ],
    "august": [
        "lush",
        "lùshìkà"
    ],
    "september": [
        "lut",
        "lutongolo"
    ],
    "october": [
        "lun",
        "lungùdi"
    ],
    "november": [
        "kas",
        "kaswèkèsè"
    ],
    "december": [
        "cis",
        "ciswà"
    ],
    "monday": [
        "nko",
        "nkodya"
    ],
    "tuesday": [
        "ndy",
        "ndàayà"
    ],
    "wednesday": [
        "ndangù",
        "ndg"
    ],
    "thursday": [
        "njw",
        "njòwa"
    ],
    "friday": [
        "ngv",
        "ngòvya"
    ],
    "saturday": [
        "lub",
        "lubingu"
    ],
    "sunday": [
        "lum",
        "lumingu"
    ],
    "am": [
        "dinda"
    ],
    "pm": [
        "dilolo"
    ],
    "year": [
        "tshidimu"
    ],
    "month": [
        "ngondo"
    ],
    "week": [
        "lubingu"
    ],
    "day": [
        "dituku"
    ],
    "hour": [
        "diba"
    ],
    "minute": [
        "kasunsu"
    ],
    "second": [
        "kasunsukusu"
    ],
    "relative-type": {
        "0 day ago": [
            "lelu"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "this month"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "this week"
        ],
        "0 year ago": [
            "this year"
        ],
        "1 day ago": [
            "makelela"
        ],
        "1 month ago": [
            "last month"
        ],
        "1 week ago": [
            "last week"
        ],
        "1 year ago": [
            "last year"
        ],
        "in 1 day": [
            "malaba"
        ],
        "in 1 month": [
            "next month"
        ],
        "in 1 week": [
            "next week"
        ],
        "in 1 year": [
            "next year"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
